@@ -18,8 +18,21 @@ from shutil import copy
 from shutil import copytree
 from tempfile import mkdtemp
 
-import osgeo.gdal as gdal
-import ogr, osr
+try:
+    import ogr
+except ImportError:
+    from osgeo import ogr
+
+try:
+    import osr
+except ImportError:
+    from osgeo import osr
+
+try:
+    import gdal
+except ImportError:
+    from osgeo import gdal
+
 import numpy as np
 from shapely.geometry import box
 
@@ -28,13 +41,10 @@ KEEP_FILENAME = ".tondor_keep"
 
 log = logging.getLogger(__name__)
 
-
 def run_subprocess(args, work_dir):
     log.debug("Calling subprocess, args={:s}.".format(repr(args)))
-    pr = subprocess.run(args, cwd=work_dir, check=False)
-    log.info("Subprocess exited with code {:d}, args={:s}.".format(pr.returncode, repr(args)))
-    pr.check_returncode()
-
+    cmd_output = subprocess.run(args, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+    log.info("Subprocess exited with code {:d}, args={:s}.".format(cmd_output.returncode, repr(args)))
 
 def log_subprocess(args, work_dir, log_filepath, timeout=None):
     log.debug("Calling subprocess: {:s}, logging to {:s}.".format(repr(args), str(log_filepath)))
@@ -368,29 +378,6 @@ def copy_singlefile_from_archive(scrfile_path, dstfile_path):
 #################################################################################################
 #################################################################################################
 
-def read_raster_info(raster_filepath):
-    ds = gdal.Open(str(raster_filepath))
-
-    gt = ds.GetGeoTransform()
-    ulx_raster = gt[0]
-    uly_raster = gt[3]
-    lrx_raster = gt[0] + gt[1] * ds.RasterXSize + gt[2] * ds.RasterYSize
-    lry_raster = gt[3] + gt[4] * ds.RasterXSize + gt[5] * ds.RasterYSize
-    imagery_extent_box = box(lrx_raster, uly_raster, ulx_raster, lry_raster)
-    ds = None
-
-    xmin = gt[0]
-    ymax = gt[3]
-    pixel_width = gt[1]
-    yres = gt[5]
-
-    projection = ds.GetProjection()
-    datatype = ds.GetRasterBand(1).DataType
-    n_bands = ds.RasterCount
-    epsg = ds.GetSpatialRef().GetAuthorityCode(None)
-
-    return (xmin, ymax, ds.RasterXSize, ds.RasterYSize, pixel_width, projection, epsg, datatype, n_bands, imagery_extent_box)
-
 def reproject_multibandraster_toextent(composite_filepath, warped_filepath, target_epsg, pixel_size, xmin, xmax, ymin, ymax, work_dir, method ='bilinear'):
 
     cmd = ["gdalwarp",
@@ -404,6 +391,20 @@ def reproject_multibandraster_toextent(composite_filepath, warped_filepath, targ
            ]
     run_subprocess(cmd, work_dir)
 
+def reproject_multibandraster_toextent_withnodata(composite_filepath, warped_filepath, target_epsg, pixel_size, xmin, xmax, ymin, ymax, work_dir, nodata_value, method ='bilinear'):
+
+    cmd = ["gdalwarp",
+           "-t_srs", "EPSG:{}".format(target_epsg),
+           "-tr", str(pixel_size), str(pixel_size),
+           "-te",str(xmin),str(ymin),str(xmax),str(ymax),
+           "-r", method,
+           "-ot", "Float32",
+           "-dstnodata", nodata_value,
+           "-co", "COMPRESS=DEFLATE",
+           str(composite_filepath),
+           str(warped_filepath)
+           ]
+    run_subprocess(cmd, work_dir)
 
 def reproject_multibandraster(composite_filepath, warped_filepath, target_epsg, pixel_size, work_dir, method ='bilinear'):
 
